OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Setu notanda lauk óvænt",
    "Provided email-address is not valid" : "Uppgefið tölvupóstfang er ekki gilt",
    "%s has published the calendar »%s«" : "%s gaf út dagatalið »%s«",
    "Unexpected error sending email. Please contact your administrator." : "Óvænt vandamál kom upp við að senda tölvupóst. Hafðu samband við kerfisstjóra.",
    "Successfully sent email to " : "Tókst að senda tölvupóst til",
    "Hello," : "Halló,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Við vildum láta þig vita að %s gaf út dagatalið »%s«.",
    "Open »%s«" : "Opna »%s«",
    "Cheers!" : "Til hamingju!",
    "Calendar" : "Dagatal",
    "A Calendar app for Nextcloud" : "Dagatalsforrit fyrir Nextcloud",
    "Previous day" : "Fyrri dagur",
    "Previous week" : "Fyrri vika",
    "Previous month" : "Fyrri mánuður",
    "Next day" : "Næsta dag",
    "Next week" : "Næsta viku",
    "Next month" : "Næsti mánuður",
    "+ New event" : "+ Nýr atburður",
    "Today" : "Í dag",
    "Day" : "Dagur",
    "Week" : "Vika",
    "Month" : "Mánuður",
    "Untitled calendar" : "Ónefnt dagatal",
    "Edit name" : "Breyta heiti",
    "Saving name …" : "Vista heiti …",
    "Edit color" : "Breyta lit",
    "Saving color …" : "Vista lit …",
    "Copy private link" : "Afrita einkatengil",
    "Download" : "Sækja",
    "Unshare from me" : "Hætta deilingu frá mér",
    "Delete" : "Eyða",
    "An error occurred, unable to change visibility of the calendar." : "Villa kom upp, gat ekki breytt sýnileika dagatalsins.",
    "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
    "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "An error occurred, unable to rename the calendar." : "Villa kom upp, gat ekki endurnefnt dagatalið.",
    "An error occurred, unable to change the calendar's color." : "Villa kom upp, gat ekki breytt lit dagatalsins.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Hætti að deila dagatalinu eftir {countdown} sekúndu","Hætti að deila dagatalinu eftir {countdown} sekúndur"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eyði dagatalinu eftir {countdown} sekúndu","Eyði dagatalinu eftir {countdown} sekúndur"],
    "Share link" : "Deila tengli",
    "Publish calendar" : "Gefa út dagatal",
    "Publishing calendar" : "Gef út dagatal",
    "Copy public link" : "Afrita opinberan tengil",
    "Send link to calendar via email" : "Senda tengil á dgatal með tölvupósti",
    "Enter one address" : "Settu inn eitt netfang",
    "Sending email …" : "Sendi tölvupóst ...",
    "Copying link …" : "Afrita tengil …",
    "Copied link" : "Afritaði tengil",
    "Could not copy link" : "Gat ekki afritað tengil",
    "Copying code …" : "Afrita kóða …",
    "Copied code" : "Afritaði kóða",
    "Could not copy code" : "Gat ekki afritað kóða",
    "Delete share link" : "Eyða tengli á sameign",
    "Deleting share link …" : "Eyði tengli á sameign …",
    "An error occurred, unable to publish calendar." : "Villa kom upp, gat ekki gefið út dagatalið.",
    "An error occurred, unable to send email." : "Villa kom upp, gat ekki sent tölvupóst.",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "can edit" : "getur breytt",
    "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
    "+ New calendar" : "+ Nýtt dagatal",
    "New calendar" : "Nýtt dagatal",
    "Creating calendar …" : "Útbý dagatal …",
    "New calendar with task list" : "Nýtt dagatal með verkefnalista",
    "An error occurred, unable to create the calendar." : "Villa kom upp, gat ekki búið til dagatalið.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Skráðu inn gilda slóð (starting with http://, https://, webcal://, or webcals://)",
    "Import calendars" : "Flytja inn dagatöl",
    "Please select a calendar to import into …" : "Veldu dagatal til að flytja inn í …",
    "Filename" : "Skráarheiti",
    "Calendar to import into" : "Dagatal til að flytja inn í",
    "Cancel" : "Hætta við",
    "_Import calendar_::_Import calendars_" : ["Flytja inn dagatal","Flytja inn dagatöl"],
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Innflutningur tókst á %n atburði","Innflutningur tókst á %n atburðum"],
    "Automatic" : "Sjálfvirkt",
    "Automatic ({detected})" : "Sjálfvirkt ({detected})",
    "New setting was not saved successfully." : "Ekki tókst að vista nýju stillinguna.",
    "Enable birthday calendar" : "Virkja fæðingardagatal",
    "Enable simplified editor" : "Virkja einfaldaðan ritil",
    "Show weekends" : "Sýna helgar",
    "Show week numbers" : "Sýna vikunúmer",
    "Copy primary CalDAV address" : "Afrita aðal-CalDAV-vistfang",
    "Copy iOS/macOS CalDAV address" : "Afrita iOS/macOS CalDAV-vistfang ",
    "Settings & import" : "Stillingar og innflutningur",
    "CalDAV link copied to clipboard." : "CalDAV-tengill afritaður á klippispjald.",
    "CalDAV link could not be copied to clipboard." : "Ekki var hægt að afrita CalDAV-tengil á klippispjald.",
    "Notification" : "Tilkynning",
    "Email" : "Tölvupóstur",
    "Edit time" : "Breyta tíma",
    "Save time" : "Vista tíma",
    "Remove reminder" : "Fjarlægja áminningu",
    "+ Add reminder" : "+ Bæta við áminningu",
    "_second_::_seconds_" : ["sekúnda","sekúndur"],
    "_minute_::_minutes_" : ["mínúta","mínútur"],
    "_hour_::_hours_" : ["klukkustund","klukkustundir"],
    "_day_::_days_" : ["dagur","dagar"],
    "_week_::_weeks_" : ["vika","vikur"],
    "No reminders yet" : "Engar áminningar ennþá",
    "Busy" : "Upptekinn",
    "Unknown" : "Óþekkt",
    "{name} accepted your invitation." : "{name} hefur samþykkt boð þitt.",
    "{name} accepted {organizerName}'s invitation." : "{name} hefur samþykkt boð frá {organizerName}.",
    "{name} declined your invitation." : "{name} hafnaði boði þínu.",
    "{name} declined {organizerName}'s invitation." : "{name} hefur hafnaði boði frá {organizerName}.",
    "{name} marked their participation as tentative." : "{name} merktu við þáttöku sína með fyrirvara as tentative.",
    "{name} did not respond to your invitation yet." : "{name} hefur ekki svarað boðinu þínu ennþá.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} hefur ekki svarað boðinu frá {organizerName} ennþá.",
    "Send e-mail" : "Senda tölvupóst",
    "Chairperson" : "Fundarstjóri",
    "Required participant" : "Nauðsynlegur þáttakandi",
    "Optional participant" : "Aukaþáttakandi",
    "Non-participant" : "Ekki þáttakandi",
    "Remove attendee" : "Fjarlægja þáttakanda",
    "Search for e-mails, users, contacts, resources or rooms" : "Leita að tölvupósti, notendum, tengiliðum, aðföngum eða fundarsölum",
    "No match found" : "Fann engar samsvaranir",
    "No attendees yet" : "Engir þáttakendur ennþá",
    "(organizer)" : "(skipuleggjandi)",
    "Event title" : "Titill atburðar",
    "All day" : "Heilsdagsviðburður",
    "Select to end repeat" : "Veldu til að hætta endurtekningu",
    "never" : "aldrei",
    "on date" : "þann",
    "after" : "eftir",
    "first" : "fyrsta",
    "third" : "þriðja",
    "fourth" : "fjórða",
    "fifth" : "fimmta",
    "last" : "síðasta",
    "Repeat" : "Endurtaka",
    "Repeat every" : "Endurtaka",
    "By day of the month" : "Eftir degi mánaðarins",
    "On the" : "Þann",
    "_month_::_months_" : ["mánuður","mánuðir"],
    "_year_::_years_" : ["ár","ár"],
    "Monday" : "Mánudagur",
    "weekday" : "vinnudagur",
    "weekend day" : "helgardagur",
    "Summary" : "Samantekt",
    "More" : "Meira",
    "Save" : "Vista",
    "Update" : "Uppfæra",
    "Update this occurrence" : "Uppfæra þetta tilviki",
    "Update this and all future" : "Uppfæra þetta og öll síðari",
    "Public calendar does not exist" : "Opinbert dagatal er ekki til",
    "Maybe the share was deleted or has expired?" : "Hugsanlega hefur sameigninni verið eytt eða hún sé útrunnin?",
    "Please select a timezone:" : "Veldu tímabelti:",
    "Select Date" : "Veldu dag",
    "Personal" : "Persónulegt",
    "Delete this occurrence" : "Eyða þessu tilviki",
    "Delete this and all future" : "Eyða þessu og framtíðar tilvikum",
    "Details" : "Nánar",
    "Attendees" : "Þáttakendur",
    "Reminders" : "Áminningar",
    "Activity" : "Virkni",
    "Projects" : "Verkefni",
    "Show more details" : "Sýna frekari upplýsingar",
    "Close" : "Loka",
    "Subscribe to {name}" : "Panta áskrift að {name}",
    "Download {name}" : "Sækja {name}",
    "Anniversary" : "Afmæli",
    "Appointment" : "Stefnumót",
    "Business" : "Viðskipti",
    "Education" : "Menntun",
    "Holiday" : "Frí",
    "Meeting" : "Fundur",
    "Miscellaneous" : "Ýmislegt",
    "Non-working hours" : "Utan vinnutíma",
    "Not in office" : "Ekki á skrifstofunni",
    "Phone call" : "Símtal",
    "Sick day" : "Veikindadagur",
    "Special occasion" : "Sérstakt tilefni",
    "Travel" : "Ferðalög",
    "Vacation" : "Í fríi",
    "Week {number} of {year}" : "Vika {number}, ársins {year}",
    "Does not repeat" : "Endurtekst ekki",
    "Daily" : "Daglega",
    "Weekly" : "Vikulega",
    "Monthly" : "Mánaðarlega",
    "Yearly" : "Árlega",
    "in {monthNames}" : "í {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "í {monthNames} þann {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "þangað til {untilDate}",
    "_%n time_::_%n times_" : ["%n sinni","%n sinnum"],
    "Untitled event" : "Ónefndur atburður",
    "When shared show" : "Þegar er deilt, birta ",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "The visibility of this event in shared calendars." : "Sýnileiki þessa atburðar í sameiginlegum dagatölum",
    "Location" : "Staðsetning",
    "Add a location" : "Bæta við staðsetningu",
    "Description" : "Lýsing",
    "Add a description" : "Settu inn lýsingu",
    "Status" : "Staða",
    "Confirmed" : "Staðfest",
    "Tentative" : "Með fyrirvara",
    "Cancelled" : "Hætt við",
    "Confirmation about the overall status of the event." : "Staðfesting á almennri stöðu atburðarins.",
    "Show as" : "Birta sem",
    "Take this event into account when calculating free-busy information." : "Taka þennan atburð með í reikninga á laus/upptekinn upplýsingum.",
    "Free" : "Laus",
    "Categories" : "Flokkar",
    "Categories help you to structure and organize your events." : "Flokkar hjálpa þér við að greina og skipuleggja atburði.",
    "Search or add categories" : "Leita eða bæta við flokkum",
    "Add this as a new category" : "Bæta þessu við sem nýjum flokki",
    "Custom color" : "Sérsniðinn litur",
    "Special color of this event. Overrides the calendar-color." : "Sértækur litur þessa atburðar. Er rétthærri en litur dagatalsins.",
    "Imported {filename}" : "Flutti inn {filename}",
    "Meditation" : "Hugleiðsla",
    "Relaxing" : "Afslöppun",
    "Presentation" : "Kynning",
    "Camping" : "Tjaldútilega",
    "Camp" : "Tjaldstæði",
    "Movie" : "Kvikmynd",
    "Cinema" : "Kvikmyndahús",
    "Graduation" : "Útskrift",
    "Brainstorm" : "Hugarflug",
    "Baseball" : "Hornabolti",
    "Meet" : "Hittast",
    "Review" : "Yfirfara",
    "Office" : "Skrifstofa",
    "Party" : "Partý",
    "Celebration" : "Hátíðahöld",
    "Mail" : "Póstur",
    "Soccer" : "Fótbolti",
    "Football" : "Ruðningsbolti",
    "Gaming" : "Spilun",
    "Play" : "Spila",
    "Game" : "Leikur",
    "Drive" : "Keyra",
    "Bicycle" : "Reiðhjól",
    "Cycle" : "Hjóla",
    "Biking" : "Hjólreiðar",
    "Podcast" : "Hlaðvarp",
    "Basketball" : "Körfubolti",
    "Fishing" : "Fiskveiði",
    "Hiking" : "Gönguferð",
    "Hike" : "Ganga",
    "Art" : "Listir",
    "Exhibition" : "Listasýning",
    "Museum" : "Safn",
    "Pilates" : "Pílates",
    "Park" : "Almenningsgarður",
    "Studying" : "Lærdómur",
    "Doctor" : "Læknir",
    "Health" : "Heilsa",
    "Dentist" : "Tannlæknir",
    "Interview" : "Viðtal",
    "Training" : "Þjálfun",
    "Sports" : "Íþróttir",
    "Exercise" : "Æfing",
    "Work out" : "Líkamsrækt",
    "Working out" : "Púla",
    "Barber" : "Rakari",
    "Haircut" : "Hárskurður",
    "Exam" : "Próf",
    "Working" : "Vinna",
    "New Years Eve" : "Gamlárskvöld",
    "NYE" : "Gamlárs",
    "Fireworks" : "Flugeldar",
    "Running" : "Hlaup",
    "Go for a run" : "Farðu út að hlaupa",
    "Marathon" : "Maraþon",
    "Call" : "Símtal",
    "Calling" : "Hringi",
    "Christmas" : "Jól",
    "Conference" : "Ráðstefna",
    "Pizza" : "Flatbaka",
    "Travelling" : "Flakk",
    "Journey" : "Ferðalag",
    "Collaborate" : "Samstarf",
    "Lecture" : "Fyrirlestur",
    "Seminar" : "Námskeið",
    "Photograph" : "Ljósmynd",
    "Celebrate" : "Fagna",
    "Shopping" : "Versla",
    "Skate" : "Skautar",
    "Skateboard" : "Hjólabretti",
    "Wine tasting" : "Vínsmökkun",
    "Golf" : "Golf",
    "Dinner" : "Kvöldverður",
    "Global" : "Víðvært"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
